@@ -292,9 +292,9 @@ class BackupEngine {
 
             // CRITICAL: Validate path to prevent directory traversal attacks
             $allowedPaths = [
-                '/docker/backups/temp/',
-                '/docker/backups/ready/',
-                '/docker/backups/failed/'
+                '/docker/backups/local/temp/',
+                '/docker/backups/local/ready/',
+                '/docker/backups/local/failed/'
             ];
 
             $realPath = realpath($localPath);
